@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: auto-update
-version: 0.1.3
-id: auto-update-0.1.3-4edf36ce78b71bfaad1ce3737442c65f
-key: autou_19qtEoqMgV6FQlA1CkY9Cg
+version: 0.1.4
+id: auto-update-0.1.4-5802161b0d99b2a30d57c95848e07a31
+key: autou_Fnqbq5K41573zil7J3s62I
 license: MIT
 maintainer: michael@snoyman.com
 homepage: https://github.com/yesodweb/wai
@@ -17,10 +17,10 @@ exposed-modules:
     Control.AutoUpdate Control.Debounce Control.Reaper
 hidden-modules: Control.AutoUpdate.Util
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/auto-update-0.1.3
-library-dirs: /usr/lib/ghc-7.10.3/site-local/auto-update-0.1.3
-data-dir: /usr/share/arm-linux-ghc-7.10.3/auto-update-0.1.3
-hs-libraries: HSauto-update-0.1.3-19qtEoqMgV6FQlA1CkY9Cg
+import-dirs: /usr/lib/ghc-7.10.3/site-local/auto-update-0.1.4
+library-dirs: /usr/lib/ghc-7.10.3/site-local/auto-update-0.1.4
+data-dir: /usr/share/arm-linux-ghc-7.10.3/auto-update-0.1.4
+hs-libraries: HSauto-update-0.1.4-Fnqbq5K41573zil7J3s62I
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
 haddock-interfaces: /usr/share/doc/haskell-auto-update/html/auto-update.haddock
